@@ -1,33 +1,35 @@
 """Tests for refleaks."""
 
-from cherrypy._cpcompat import HTTPConnection, HTTPSConnection, ntob
+import itertools
+import platform
 import threading
 
 import cherrypy
+from cherrypy._cpcompat import HTTPConnection, HTTPSConnection
+from cherrypy.test import helper
 
 
 data = object()
 
 
-from cherrypy.test import helper
-
-
 class ReferenceTests(helper.CPWebCase):
 
+    @staticmethod
     def setup_server():
 
         class Root:
 
+            @cherrypy.expose
             def index(self, *args, **kwargs):
                 cherrypy.request.thing = data
-                return "Hello world!"
-            index.exposed = True
+                return 'Hello world!'
 
         cherrypy.tree.mount(Root())
-    setup_server = staticmethod(setup_server)
 
     def test_threadlocal_garbage(self):
-        success = []
+        if platform.system() == 'Darwin':
+            self.skip('queue issues; see #1474')
+        success = itertools.count()
 
         def getpage():
             host = '%s:%s' % (self.interface(), self.PORT)
@@ -41,19 +43,22 @@ class ReferenceTests(helper.CPWebCase):
                 response = c.getresponse()
                 body = response.read()
                 self.assertEqual(response.status, 200)
-                self.assertEqual(body, ntob("Hello world!"))
+                self.assertEqual(body, b'Hello world!')
             finally:
                 c.close()
-            success.append(True)
+            next(success)
 
         ITERATIONS = 25
-        ts = []
-        for _ in range(ITERATIONS):
-            t = threading.Thread(target=getpage)
-            ts.append(t)
+
+        ts = [
+            threading.Thread(target=getpage)
+            for _ in range(ITERATIONS)
+        ]
+
+        for t in ts:
             t.start()
 
         for t in ts:
             t.join()
 
-        self.assertEqual(len(success), ITERATIONS)
+        self.assertEqual(next(success), ITERATIONS)
